==> hindent-5.3.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.3.1
id: hindent-5.3.1-L1bDb7gzhPb4e6zwWitxYp
key: hindent-5.3.1-L1bDb7gzhPb4e6zwWitxYp
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: 400193b2d770aa930a2456a3f9d1f2f6
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.3.1-L1bDb7gzhPb4e6zwWitxYp
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    filepath-1.4.2.1 haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.2.0-BIsjRIkW1eUC5z8TOsGDnT
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.3.1-35-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.3.1
id: hindent-5.3.1-58o0rutQA4U3ue1D6W1tF9
key: hindent-5.3.1-58o0rutQA4U3ue1D6W1tF9
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: b42829aca0c0d4303049a200ffb76bbe
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hindent-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.3.1-58o0rutQA4U3ue1D6W1tF9
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    filepath-1.4.2.1 haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.2.0-IFpV4kshDss3NuviLLmj7e
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
